{% load i18n %}
<tr>
  <th>{% trans "Contents" %}</th>
  <th>{% trans "Discussions" %}</th>
</tr>
<tr>
  <td>
    <a href="{% url 'admin:zinnia_entry_changelist' %}">
      {% blocktrans count entry_count=entries %}{{ entry_count }} entry{% plural %}{{ entry_count }} entries{% endblocktrans %}
    </a>
  </td>
  <td>
    <a href="{% url 'admin:zinnia_threaded_comments_threadedcomment_changelist' %}?is_public__exact=1">
      {% blocktrans count comment_count=comments %}{{ comment_count }} comment{% plural %}{{ comment_count }} comments{% endblocktrans %}
    </a>
  </td>
</tr>
<tr>
  <td>
    <a href="{% url 'admin:zinnia_category_changelist' %}">
      {% blocktrans count category_count=categories %}{{ category_count }} category{% plural %}{{ category_count }} categories{% endblocktrans %}
    </a>
  </td>
  <td>{% blocktrans count pingback_count=pingbacks %}{{ pingback_count }} pingback{% plural %}{{ pingback_count }} pingbacks{% endblocktrans %}</td>
</tr>
<tr>
  <td>
    <a href="{% url 'admin:tagging_tag_changelist' %}">
      {% blocktrans count tag_count=tags %}{{ tag_count }} tag{% plural %}{{ tag_count }} tags{% endblocktrans %}
    </a>
  </td>
  <td>{% blocktrans count trackback_count=trackbacks %}{{ trackback_count }} trackback{% plural %}{{ trackback_count }} trackbacks{% endblocktrans %}</td>
</tr>
<tr>
  <td>
    <a href="{% url 'admin:auth_user_changelist' %}">
      {% blocktrans count author_count=authors %}{{ author_count }} author{% plural %}{{ author_count }} authors{% endblocktrans %}
    </a>
  </td>
  <td>
    <a href="{% url 'admin:zinnia_threaded_comments_threadedcomment_changelist' %}?is_public__exact=0">
      {% blocktrans count reject_count=rejects %}{{ reject_count }} rejected item{% plural %}{{ reject_count }} rejected items{% endblocktrans %}
    </a>
  </td>
</tr>
<tr>
  <th>{% trans "Statistics" %}</th>
  <td>
    {% blocktrans with entries_per_month=entries_per_month|floatformat:2 %}{{ entries_per_month }} entries per month{% endblocktrans %}
  </td>
</tr>
<tr>
  <td>
    {% blocktrans with words_per_entry=words_per_entry|floatformat:2 %}{{ words_per_entry }} words per entry{% endblocktrans %}
  </td>
  <td>
    {% blocktrans with words_per_comment=words_per_comment|floatformat:2 %}{{ words_per_comment }} words per comment{% endblocktrans %}
  </td>
</tr>
<tr>
  <td>
    {% blocktrans with comments_per_entry=comments_per_entry|floatformat:2 %}{{ comments_per_entry }} comments per entry{% endblocktrans %}
  </td>
  <td>
    {% blocktrans with linkbacks_per_entry=linkbacks_per_entry|floatformat:2 %}{{ linkbacks_per_entry }} linkbacks per entry{% endblocktrans %}
  </td>
</tr>
