p.comment-reply {
  margin: 0 0 0.5em 0;
  text-align: right;
  a:after {
    content: "\21d3";
  }
}

#cancel-comment-reply {
  float: right;
  &:before {
    content: "\2297  ";
  }
}

#comment-list {
  li.reply {
    padding: 0;
  }
}

