"""Initial state of the comments"""
from south.db import db
from south.v2 import SchemaMigration


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'ThreadedComment'
        db.create_table('zinnia_threaded_comments_threadedcomment', (
            ('comment_ptr',
             self.gf('django.db.models.fields.related.OneToOneField')(
                 unique=True, primary_key=True,
                 to=orm['comments.Comment'])),
            ('parent',
             self.gf('mptt.fields.TreeForeignKey')(
                 blank=True, related_name='children', null=True,
                 to=orm['zinnia_threaded_comments.ThreadedComment'])),
            ('lft',
             self.gf('django.db.models.fields.PositiveIntegerField')(
                 db_index=True)),
            ('rght',
             self.gf('django.db.models.fields.PositiveIntegerField')(
                 db_index=True)),
            ('tree_id',
             self.gf('django.db.models.fields.PositiveIntegerField')(
                 db_index=True)),
            ('level',
             self.gf('django.db.models.fields.PositiveIntegerField')(
                 db_index=True)),
        ))
        db.send_create_signal('zinnia_threaded_comments', ['ThreadedComment'])

    def backwards(self, orm):
        # Deleting model 'ThreadedComment'
        db.delete_table('zinnia_threaded_comments_threadedcomment')

    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField',
                   [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField',
                     [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField',
                            [], {'to': "orm['auth.Permission']",
                                 'symmetrical': 'False',
                                 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', "
                     "'content_type__model', 'codename')",
                     'unique_together': "(('content_type', 'codename'),)",
                     'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField',
                         [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey',
                             [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField',
                   [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField',
                     [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField',
                            [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField',
                      [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField',
                           [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField',
                       [], {'to': "orm['auth.Group']",
                            'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField',
                   [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField',
                          [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField',
                         [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField',
                             [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField',
                           [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField',
                          [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField',
                         [], {'max_length': '128'}),
            'user_permissions': (
                'django.db.models.fields.related.ManyToManyField',
                [], {'to': "orm['auth.Permission']",
                     'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField',
                         [], {'unique': 'True', 'max_length': '30'})
        },
        'comments.comment': {
            'Meta': {'ordering': "('submit_date',)",
                     'object_name': 'Comment',
                     'db_table': "'django_comments'"},
            'comment': ('django.db.models.fields.TextField',
                        [], {'max_length': '3000'}),
            'content_type': ('django.db.models.fields.related.ForeignKey',
                             [],
                             {'related_name': "'content_type_set_for_comment'",
                              'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField',
                   [], {'primary_key': 'True'}),
            'ip_address': ('django.db.models.fields.IPAddressField',
                           [], {'max_length': '15', 'null': 'True',
                                'blank': 'True'}),
            'is_public': ('django.db.models.fields.BooleanField',
                          [], {'default': 'True'}),
            'is_removed': ('django.db.models.fields.BooleanField',
                           [], {'default': 'False'}),
            'object_pk': ('django.db.models.fields.TextField',
                          [], {}),
            'site': ('django.db.models.fields.related.ForeignKey',
                     [], {'to': "orm['sites.Site']"}),
            'submit_date': ('django.db.models.fields.DateTimeField',
                            [], {'default': 'None'}),
            'user': ('django.db.models.fields.related.ForeignKey',
                     [], {'blank': 'True',
                          'related_name': "'comment_comments'",
                          'null': 'True', 'to': "orm['auth.User']"}),
            'user_email': ('django.db.models.fields.EmailField',
                           [], {'max_length': '75', 'blank': 'True'}),
            'user_name': ('django.db.models.fields.CharField',
                          [], {'max_length': '50', 'blank': 'True'}),
            'user_url': ('django.db.models.fields.URLField',
                         [], {'max_length': '200', 'blank': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)",
                     'unique_together': "(('app_label', 'model'),)",
                     'object_name': 'ContentType',
                     'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField',
                          [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField',
                   [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField',
                      [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField',
                     [], {'max_length': '100'})
        },
        'sites.site': {
            'Meta': {'ordering': "('domain',)",
                     'object_name': 'Site',
                     'db_table': "'django_site'"},
            'domain': ('django.db.models.fields.CharField',
                       [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField',
                   [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField',
                     [], {'max_length': '50'})
        },
        'zinnia_threaded_comments.threadedcomment': {
            'Meta': {'object_name': 'ThreadedComment',
                     '_ormbases': ['comments.Comment']},
            'comment_ptr': ('django.db.models.fields.related.OneToOneField',
                            [], {'to': "orm['comments.Comment']",
                                 'unique': 'True', 'primary_key': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField',
                      [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField',
                    [], {'db_index': 'True'}),
            'parent': ('mptt.fields.TreeForeignKey',
                       [], {'blank': 'True',
                            'related_name': "'children'",
                            'null': 'True',
                            'to': "orm['zinnia_threaded_comments."
                            "ThreadedComment']"}),
            'rght': ('django.db.models.fields.PositiveIntegerField',
                     [], {'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField',
                        [], {'db_index': 'True'})
        }
    }

    complete_apps = ['zinnia_threaded_comments']
